%define __python %{__python3}

# comment out when not pre-release
%define	prel	svn20190422

%define rel	9

Name:		canorus
Version:	0.7.3
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	A music score editor
Group:		Education
License:	GPLv3
Url:		http://canorus.sourceforge.net
Source:		https://sourceforge.net/projects/canorus/files/%{version}/%{name}-%{version}%{?prel}.tar.bz2
# userguide does not honour DESTDIR: add it
Patch1:		%{name}-0.7.3-DESTDIR.patch
# https://sourceforge.net/p/canorus/bugs/50/
Patch2:		%{name}-0.7.3-qt-translations.patch
# userguid was not installed, hide from menu
Patch3:		%{name}-0.7.3-no-userguid.patch

BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5PrintSupport)
BuildRequires:	pkgconfig(Qt5Qml)
BuildRequires:	pkgconfig(Qt5Quick)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5WebEngineWidgets)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	pkgconfig(alsa)

Recommends:		qttranslations5

%description
Canorus is a free cross-platform music score editor.
It supports an unlimited number and length of staffs, polyphony,
a MIDI playback of notes, chord markings, lyrics, import/export filters
to formats like MIDI, MusicXML, ABC Music, MusiXTeX and LilyPond.

%package doc
Summary:	Canorus documentation
Group:		Documentation
BuildArch:	noarch

%description doc
Canorus developers guide.
The documentation is available in many formats:
	* PDF
	* Html
	* Qt Help

%prep
%setup -q -n %{name}-%{version}%{?prel}
%autopatch -p1

# set correct version
echo %{version}%{?prel} > VERSION

%build
%cmake_qt5 \
	-DNO_RUBY:BOOL=TRUE \
	-DNO_SWIG:BOOL=TRUE \
	-DNO_PYTHON:BOOL=TRUE
%cmake_build

pushd doc
pushd developersguide
%make_build
popd

#pushd usersguide2
#make_build all
#popd
popd

%install
%cmake_install

# desktop file
mkdir -p %{buildroot}%{_datadir}/applications
install -m 644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

# manpage
mkdir -p %{buildroot}%{_mandir}/man6
install -m 644 debian/canorus.6 %{buildroot}%{_mandir}/man6/%{name}.6

# doc files
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -R doc/developersguide %{buildroot}%{_docdir}/%{name}/
#cp -R doc/usersguide2 %%{buildroot}%%{_datadir}/%%{name}/doc/

# cleanup
find %{buildroot}%{_docdir}/%{name} -name "Makefile*" -type f -delete
find %{buildroot}%{_docdir}/%{name} -name "cmake*" -type f -delete
rm -rf %{buildroot}%{_datadir}/%{name}/{README,NEWS,AUTHORS,DEVELOPERS,COPYING,VERSION}

%files
%doc README NEWS AUTHORS DEVELOPERS VERSION
%license COPYING
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/examples/
%{_datadir}/%{name}/images/
%{_datadir}/%{name}/fonts/
%{_datadir}/%{name}/lang/
%{_datadir}/%{name}/plugins/
%{_datadir}/%{name}/scripts/
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man6/%{name}.6.*

%files doc
%doc doc/Readme-doc.txt
%{_docdir}/%{name}/


%changelog
* Wed Dec 16 2020 umeabot <umeabot> 0.7.3-0.svn20190422.9.mga8
+ Revision: 1658185
- Rebuild for new Qt5
+ danf <danf>
- Switch URLs from http: to https:

* Sat Feb 15 2020 umeabot <umeabot> 0.7.3-0.svn20190422.8.mga8
+ Revision: 1526115
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Tue Apr 23 2019 alexl <alexl> 0.7.3-0.svn20190422.7.mga7
+ Revision: 1394875
- the latest svn snapshot
- delete upstreamed translations
- use desktop file and icon from upstream

* Mon Apr 22 2019 alexl <alexl> 0.7.3-0.svn20190105.6.mga7
+ Revision: 1394617
- the latest svn snapshot
- enable brp_python_bytecompile
- hide userguid from menu (it was not installed)
- removed deprecated BR
- update description for doc subpackage

* Fri Apr 19 2019 alexl <alexl> 0.7.3-0.rc1.5.mga7
+ Revision: 1393375
- fix translation for qt strings
- fix localization by installation of QM files (workaround)

* Thu Apr 18 2019 alexl <alexl> 0.7.3-0.rc1.4.mga7
+ Revision: 1393137
- add Russian translation

* Sat Mar 30 2019 umeabot <umeabot> 0.7.3-0.rc1.3.mga7
+ Revision: 1381398
- Qt5 Rebuild

* Sat Sep 22 2018 umeabot <umeabot> 0.7.3-0.rc1.2.mga7
+ Revision: 1295970
- Mageia 7 Mass Rebuild

* Sat May 19 2018 daviddavid <daviddavid> 0.7.3-0.rc1.1.mga7
+ Revision: 1230485
- new version: 0.7.3rc1
- port to Qt5
- add patch to fix build with gcc7
- clean %%install section

* Sun Jan 17 2016 daviddavid <daviddavid> 0.7-9.mga6
+ Revision: 924883
- add missing BR on pkgconfig(alsa)
- fix owner of data dir

* Tue Oct 27 2015 daviddavid <daviddavid> 0.7-8.mga6
+ Revision: 895738
- remove empty lang files to fix build with latest rpm

* Wed Oct 15 2014 umeabot <umeabot> 0.7-7.mga5
+ Revision: 741724
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7-6.mga5
+ Revision: 678304
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 0.7-5.mga4
+ Revision: 545812
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 luigiwalser <luigiwalser> 0.7-4.mga4
+ Revision: 501855
- BR texlive-texmf

* Fri Jan 11 2013 umeabot <umeabot> 0.7-3.mga3
+ Revision: 347382
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Apr 02 2012 matteo <matteo> 0.7-2.mga2
+ Revision: 227951
- removed unuseful items into doc subpackage
- fixed missing buildrequire (imagemagick)
- added italian translations
- added missing buildrequire (graphviz)
- fixed missing application menu icon
- removed wrong directory into -doc subpackage
- added Education category to desktop file

* Fri Feb 10 2012 matteo <matteo> 0.7-1.mga2
+ Revision: 207073
- replaced partial cmake_zlib patch with explicit-link patch
- cmake added as br
- removed makefiles
- desktop file patch added
- usersguide makefile patch added
- doc subpackage added
- patch to add zlib to target_link_libraries
- commented items about python component that don't build with swing2
- imported package canorus

